Enum crossbeam_channel::RecvTimeoutError [−][src]
pub enum RecvTimeoutError {
Timeout,
Disconnected,
}An error returned from the recv_timeout method.
Variants
A message could not be received because the channel is empty and the operation timed out.
If this is a zero-capacity channel, then the error indicates that there was no sender available to send a message and the operation timed out.
The message could not be received because the channel is empty and disconnected.
Implementations
impl RecvTimeoutError[src]
impl RecvTimeoutError[src]pub fn is_timeout(&self) -> bool[src]
Returns true if the receive operation timed out.
pub fn is_disconnected(&self) -> bool[src]
Returns true if the receive operation failed because the channel is disconnected.