Enum crossbeam_channel::TryRecvError [−][src]
pub enum TryRecvError {
Empty,
Disconnected,
}An error returned from the try_recv method.
Variants
A message could not be received because the channel is empty.
If this is a zero-capacity channel, then the error indicates that there was no sender available to send a message at the time.
The message could not be received because the channel is empty and disconnected.
Implementations
impl TryRecvError[src]
impl TryRecvError[src]Trait Implementations
impl Clone for TryRecvError[src]
impl Clone for TryRecvError[src]fn clone(&self) -> TryRecvError[src]
pub fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Error for TryRecvError[src]
impl Error for TryRecvError[src]impl From<RecvError> for TryRecvError[src]
impl From<RecvError> for TryRecvError[src]fn from(err: RecvError) -> TryRecvError[src]
impl PartialEq<TryRecvError> for TryRecvError[src]
impl PartialEq<TryRecvError> for TryRecvError[src]