Struct ReadyTimeoutError

struct ReadyTimeoutError

An error returned from the ready_timeout method.

Failed because none of the channel operations became ready before the timeout.

Implementations

impl Clone for ReadyTimeoutError

fn clone(self: &Self) -> ReadyTimeoutError

impl Copy for ReadyTimeoutError

impl Debug for ReadyTimeoutError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for ReadyTimeoutError

impl Freeze for ReadyTimeoutError

impl PartialEq for ReadyTimeoutError

fn eq(self: &Self, other: &ReadyTimeoutError) -> bool

impl RefUnwindSafe for ReadyTimeoutError

impl Send for ReadyTimeoutError

impl StructuralPartialEq for ReadyTimeoutError

impl Sync for ReadyTimeoutError

impl Unpin for ReadyTimeoutError

impl UnsafeUnpin for ReadyTimeoutError

impl UnwindSafe for ReadyTimeoutError

impl<T> Any for ReadyTimeoutError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ReadyTimeoutError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ReadyTimeoutError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ReadyTimeoutError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ReadyTimeoutError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ReadyTimeoutError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ReadyTimeoutError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ReadyTimeoutError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ReadyTimeoutError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>