Enum RecvTimeoutError
enum RecvTimeoutError
An error returned from the recv_timeout method.
Variants
-
Timeout A message could not be received because the channel is empty and the operation timed out.
If this is a zero-capacity channel, then the error indicates that there was no sender available to send a message and the operation timed out.
-
Disconnected The message could not be received because the channel is empty and disconnected.
Implementations
impl RecvTimeoutError
fn is_timeout(self: &Self) -> boolReturns
trueif the receive operation timed out.fn is_disconnected(self: &Self) -> boolReturns
trueif the receive operation failed because the channel is disconnected.
impl Clone for RecvTimeoutError
fn clone(self: &Self) -> RecvTimeoutError
impl Copy for RecvTimeoutError
impl Debug for RecvTimeoutError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for RecvTimeoutError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for RecvTimeoutError
impl Error for RecvTimeoutError
impl Freeze for RecvTimeoutError
impl From for RecvTimeoutError
fn from(err: RecvError) -> RecvTimeoutError
impl PartialEq for RecvTimeoutError
fn eq(self: &Self, other: &RecvTimeoutError) -> bool
impl RefUnwindSafe for RecvTimeoutError
impl Send for RecvTimeoutError
impl StructuralPartialEq for RecvTimeoutError
impl Sync for RecvTimeoutError
impl Unpin for RecvTimeoutError
impl UnsafeUnpin for RecvTimeoutError
impl UnwindSafe for RecvTimeoutError
impl<T> Any for RecvTimeoutError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RecvTimeoutError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RecvTimeoutError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for RecvTimeoutError
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for RecvTimeoutError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for RecvTimeoutError
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for RecvTimeoutError
fn to_string(self: &Self) -> String
impl<T, U> Into for RecvTimeoutError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RecvTimeoutError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RecvTimeoutError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>