Function never
fn never<T>() -> Receiver<T>
Creates a receiver that never delivers messages.
The channel is bounded with capacity of 0 and never gets disconnected.
Examples
Using a never channel to optionally add a timeout to select!:
use thread;
use Duration;
use ;
let = unbounded;
spawn;
// Suppose this duration can be a `Some` or a `None`.
let duration = Some;
// Create a channel that times out after the specified duration.
let timeout = duration
.map
.unwrap_or;
select!