Struct Iter
struct Iter<'a, T> { ... }
A blocking iterator over messages in a channel.
Each call to next blocks waiting for the next message and then returns it. However, if the
channel becomes empty and disconnected, it returns None without blocking.
Examples
use thread;
use unbounded;
let = unbounded;
spawn;
// Collect all messages from the channel.
// Note that the call to `collect` blocks until the sender is dropped.
let v: = r.iter.collect;
assert_eq!;
Implementations
impl<'a, T> Freeze for Iter<'a, T>
impl<'a, T> RefUnwindSafe for Iter<'a, T>
impl<'a, T> Send for Iter<'a, T>
impl<'a, T> Sync for Iter<'a, T>
impl<'a, T> Unpin for Iter<'a, T>
impl<'a, T> UnsafeUnpin for Iter<'a, T>
impl<'a, T> UnwindSafe for Iter<'a, T>
impl<I> IntoIterator for Iter<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for Iter<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Iter<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Iter<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Debug for Iter<'_, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> From for Iter<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for Iter<'_, T>
impl<T> Iterator for Iter<'_, T>
fn next(self: &mut Self) -> Option<<Self as >::Item>
impl<T, U> Into for Iter<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Iter<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Iter<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>