Struct Select
struct Select<'a> { ... }
Selects from a set of channel operations.
Select allows you to define a set of channel operations, wait until any one of them becomes
ready, and finally execute it. If multiple operations are ready at the same time, a random one
among them is selected.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
The select! macro is a convenience wrapper around Select. However, it cannot select over a
dynamically created list of channel operations.
Once a list of operations has been built with Select, there are two different ways of
proceeding:
-
Select an operation with
try_select,select, orselect_timeout. If successful, the returned selected operation has already begun and must be completed. If we don't complete it, a panic will occur. -
Wait for an operation to become ready with
try_ready,ready, orready_timeout. If successful, we may attempt to execute the operation, but are not obliged to. In fact, it's possible for another thread to make the operation not ready just before we try executing it, so it's wise to use a retry loop. However, note that these methods might return with success spuriously, so it's a good idea to always double check if the operation is really ready.
Examples
Use select to receive a message from a list of receivers:
use ;
Use ready to receive a message from a list of receivers:
use ;
Implementations
impl<'a> Select<'a>
fn new() -> Select<'a>Creates an empty list of channel operations for selection.
Examples
use Select; let mut sel = new; // The list of operations is empty, which means no operation can be selected. assert!;fn send<T>(self: &mut Self, s: &'a Sender<T>) -> usizeAdds a send operation.
Returns the index of the added operation.
Examples
use ; let = ; let mut sel = new; let index = sel.send;fn recv<T>(self: &mut Self, r: &'a Receiver<T>) -> usizeAdds a receive operation.
Returns the index of the added operation.
Examples
use ; let = ; let mut sel = new; let index = sel.recv;fn remove(self: &mut Self, index: usize)Removes a previously added operation.
This is useful when an operation is selected because the channel got disconnected and we want to try again to select a different operation instead.
If new operations are added after removing some, the indices of removed operations will not be reused.
Panics
An attempt to remove a non-existing or already removed operation will panic.
Examples
use ; let = ; let = ; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // Both operations are initially ready, so a random one will be executed. let oper = sel.select; assert_eq!; assert!; sel.remove; s1.send.unwrap; let oper = sel.select; assert_eq!; assert_eq!;fn try_select(self: &mut Self) -> Result<SelectedOperation<'a>, TrySelectError>Attempts to select one of the operations without blocking.
If an operation is ready, it is selected and returned. If multiple operations are ready at the same time, a random one among them is selected. If none of the operations are ready, an error is returned.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
The selected operation must be completed with
SelectedOperation::sendorSelectedOperation::recv.Examples
use ; let = unbounded; let = unbounded; s1.send.unwrap; s2.send.unwrap; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // Both operations are initially ready, so a random one will be executed. let oper = sel.try_select; match operfn select(self: &mut Self) -> SelectedOperation<'a>Blocks until one of the operations becomes ready and selects it.
Once an operation becomes ready, it is selected and returned. If multiple operations are ready at the same time, a random one among them is selected.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
The selected operation must be completed with
SelectedOperation::sendorSelectedOperation::recv.Panics
Panics if no operations have been added to
Select.Examples
use thread; use Duration; use ; let = unbounded; let = unbounded; spawn; spawn; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // The second operation will be selected because it becomes ready first. let oper = sel.select; match oper.indexfn select_timeout(self: &mut Self, timeout: Duration) -> Result<SelectedOperation<'a>, SelectTimeoutError>Blocks for a limited time until one of the operations becomes ready and selects it.
If an operation becomes ready, it is selected and returned. If multiple operations are ready at the same time, a random one among them is selected. If none of the operations become ready for the specified duration, an error is returned.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
The selected operation must be completed with
SelectedOperation::sendorSelectedOperation::recv.Examples
use thread; use Duration; use ; let = unbounded; let = unbounded; spawn; spawn; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // The second operation will be selected because it becomes ready first. let oper = sel.select_timeout; match operfn select_deadline(self: &mut Self, deadline: Instant) -> Result<SelectedOperation<'a>, SelectTimeoutError>Blocks until a given deadline, or until one of the operations becomes ready and selects it.
If an operation becomes ready, it is selected and returned. If multiple operations are ready at the same time, a random one among them is selected. If none of the operations become ready before the given deadline, an error is returned.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
The selected operation must be completed with
SelectedOperation::sendorSelectedOperation::recv.Examples
use thread; use ; use ; let = unbounded; let = unbounded; spawn; spawn; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; let deadline = now + from_millis; // The second operation will be selected because it becomes ready first. let oper = sel.select_deadline; match operfn try_ready(self: &mut Self) -> Result<usize, TryReadyError>Attempts to find a ready operation without blocking.
If an operation is ready, its index is returned. If multiple operations are ready at the same time, a random one among them is chosen. If none of the operations are ready, an error is returned.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
Note that this method might return with success spuriously, so it's a good idea to always double check if the operation is really ready.
Examples
use ; let = unbounded; let = unbounded; s1.send.unwrap; s2.send.unwrap; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // Both operations are initially ready, so a random one will be chosen. match sel.try_readyfn ready(self: &mut Self) -> usizeBlocks until one of the operations becomes ready.
Once an operation becomes ready, its index is returned. If multiple operations are ready at the same time, a random one among them is chosen.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
Note that this method might return with success spuriously, so it's a good idea to always double check if the operation is really ready.
Panics
Panics if no operations have been added to
Select.Examples
use thread; use Duration; use ; let = unbounded; let = unbounded; spawn; spawn; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // The second operation will be selected because it becomes ready first. match sel.readyfn ready_timeout(self: &mut Self, timeout: Duration) -> Result<usize, ReadyTimeoutError>Blocks for a limited time until one of the operations becomes ready.
If an operation becomes ready, its index is returned. If multiple operations are ready at the same time, a random one among them is chosen. If none of the operations become ready for the specified duration, an error is returned.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
Note that this method might return with success spuriously, so it's a good idea to double check if the operation is really ready.
Examples
use thread; use Duration; use ; let = unbounded; let = unbounded; spawn; spawn; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // The second operation will be selected because it becomes ready first. match sel.ready_timeoutfn ready_deadline(self: &mut Self, deadline: Instant) -> Result<usize, ReadyTimeoutError>Blocks until a given deadline, or until one of the operations becomes ready.
If an operation becomes ready, its index is returned. If multiple operations are ready at the same time, a random one among them is chosen. If none of the operations become ready before the deadline, an error is returned.
An operation is considered to be ready if it doesn't have to block. Note that it is ready even when it will simply return an error because the channel is disconnected.
Note that this method might return with success spuriously, so it's a good idea to double check if the operation is really ready.
Examples
use thread; use ; use ; let deadline = now + from_millis; let = unbounded; let = unbounded; spawn; spawn; let mut sel = new; let oper1 = sel.recv; let oper2 = sel.recv; // The second operation will be selected because it becomes ready first. match sel.ready_deadline
impl Debug for Select<'_>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Send for Select<'_>
impl Sync for Select<'_>
impl<'a> Clone for Select<'a>
fn clone(self: &Self) -> Select<'a>
impl<'a> Default for Select<'a>
fn default() -> Select<'a>
impl<'a> Freeze for Select<'a>
impl<'a> RefUnwindSafe for Select<'a>
impl<'a> Unpin for Select<'a>
impl<'a> UnsafeUnpin for Select<'a>
impl<'a> UnwindSafe for Select<'a>
impl<T> Any for Select<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Select<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Select<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Select<'a>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Select<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Select<'a>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Select<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Select<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Select<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>