Struct Sender

struct Sender<T> { ... }

The sending side of a channel.

Examples

use std::thread;
use crossbeam_channel::unbounded;

let (s1, r) = unbounded();
let s2 = s1.clone();

thread::spawn(move || s1.send(1).unwrap());
thread::spawn(move || s2.send(2).unwrap());

let msg1 = r.recv().unwrap();
let msg2 = r.recv().unwrap();

assert_eq!(msg1 + msg2, 3);

Implementations

impl<T> Sender<T>

fn try_send(self: &Self, msg: T) -> Result<(), TrySendError<T>>

Attempts to send a message into the channel without blocking.

This method will either send a message into the channel immediately or return an error if the channel is full or disconnected. The returned error contains the original message.

If called on a zero-capacity channel, this method will send the message only if there happens to be a receive operation on the other side of the channel at the same time.

Examples

use crossbeam_channel::{bounded, TrySendError};

let (s, r) = bounded(1);

assert_eq!(s.try_send(1), Ok(()));
assert_eq!(s.try_send(2), Err(TrySendError::Full(2)));

drop(r);
assert_eq!(s.try_send(3), Err(TrySendError::Disconnected(3)));
fn send(self: &Self, msg: T) -> Result<(), SendError<T>>

Blocks the current thread until a message is sent or the channel is disconnected.

If the channel is full and not disconnected, this call will block until the send operation can proceed. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.

If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.

Examples

use std::thread;
use std::time::Duration;
use crossbeam_channel::{bounded, SendError};

let (s, r) = bounded(1);
assert_eq!(s.send(1), Ok(()));

thread::spawn(move || {
    assert_eq!(r.recv(), Ok(1));
    thread::sleep(Duration::from_secs(1));
    drop(r);
});

assert_eq!(s.send(2), Ok(()));
assert_eq!(s.send(3), Err(SendError(3)));
fn send_timeout(self: &Self, msg: T, timeout: Duration) -> Result<(), SendTimeoutError<T>>

Waits for a message to be sent into the channel, but only for a limited time.

If the channel is full and not disconnected, this call will block until the send operation can proceed or the operation times out. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.

If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.

Examples

use std::thread;
use std::time::Duration;
use crossbeam_channel::{bounded, SendTimeoutError};

let (s, r) = bounded(0);

thread::spawn(move || {
    thread::sleep(Duration::from_secs(1));
    assert_eq!(r.recv(), Ok(2));
    drop(r);
});

assert_eq!(
    s.send_timeout(1, Duration::from_millis(500)),
    Err(SendTimeoutError::Timeout(1)),
);
assert_eq!(
    s.send_timeout(2, Duration::from_secs(1)),
    Ok(()),
);
assert_eq!(
    s.send_timeout(3, Duration::from_millis(500)),
    Err(SendTimeoutError::Disconnected(3)),
);
fn send_deadline(self: &Self, msg: T, deadline: Instant) -> Result<(), SendTimeoutError<T>>

Waits for a message to be sent into the channel, but only until a given deadline.

If the channel is full and not disconnected, this call will block until the send operation can proceed or the operation times out. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.

If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.

Examples

use std::thread;
use std::time::{Duration, Instant};
use crossbeam_channel::{bounded, SendTimeoutError};

let (s, r) = bounded(0);

thread::spawn(move || {
    thread::sleep(Duration::from_secs(1));
    assert_eq!(r.recv(), Ok(2));
    drop(r);
});

let now = Instant::now();

assert_eq!(
    s.send_deadline(1, now + Duration::from_millis(500)),
    Err(SendTimeoutError::Timeout(1)),
);
assert_eq!(
    s.send_deadline(2, now + Duration::from_millis(1500)),
    Ok(()),
);
assert_eq!(
    s.send_deadline(3, now + Duration::from_millis(2000)),
    Err(SendTimeoutError::Disconnected(3)),
);
fn is_empty(self: &Self) -> bool

Returns true if the channel is empty.

Note: Zero-capacity channels are always empty.

Examples

use crossbeam_channel::unbounded;

let (s, r) = unbounded();
assert!(s.is_empty());

s.send(0).unwrap();
assert!(!s.is_empty());
fn is_full(self: &Self) -> bool

Returns true if the channel is full.

Note: Zero-capacity channels are always full.

Examples

use crossbeam_channel::bounded;

let (s, r) = bounded(1);

assert!(!s.is_full());
s.send(0).unwrap();
assert!(s.is_full());
fn len(self: &Self) -> usize

Returns the number of messages in the channel.

Examples

use crossbeam_channel::unbounded;

let (s, r) = unbounded();
assert_eq!(s.len(), 0);

s.send(1).unwrap();
s.send(2).unwrap();
assert_eq!(s.len(), 2);
fn capacity(self: &Self) -> Option<usize>

If the channel is bounded, returns its capacity.

Examples

use crossbeam_channel::{bounded, unbounded};

let (s, _) = unbounded::<i32>();
assert_eq!(s.capacity(), None);

let (s, _) = bounded::<i32>(5);
assert_eq!(s.capacity(), Some(5));

let (s, _) = bounded::<i32>(0);
assert_eq!(s.capacity(), Some(0));
fn same_channel(self: &Self, other: &Sender<T>) -> bool

Returns true if senders belong to the same channel.

Examples

use crossbeam_channel::unbounded;

let (s, _) = unbounded::<usize>();

let s2 = s.clone();
assert!(s.same_channel(&s2));

let (s3, _) = unbounded();
assert!(!s.same_channel(&s3));

impl<T> Any for Sender<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Sender<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Sender<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> Clone for Sender<T>

fn clone(self: &Self) -> Self

impl<T> CloneToUninit for Sender<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Debug for Sender<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Drop for Sender<T>

fn drop(self: &mut Self)

impl<T> Freeze for Sender<T>

impl<T> From for Sender<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for Sender<T>

impl<T> SelectHandle for Sender<T>

fn try_select(self: &Self, token: &mut Token) -> bool
fn deadline(self: &Self) -> Option<Instant>
fn register(self: &Self, oper: Operation, cx: &Context) -> bool
fn unregister(self: &Self, oper: Operation)
fn accept(self: &Self, token: &mut Token, cx: &Context) -> bool
fn is_ready(self: &Self) -> bool
fn watch(self: &Self, oper: Operation, cx: &Context) -> bool
fn unwatch(self: &Self, oper: Operation)

impl<T> ToOwned for Sender<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> Unpin for Sender<T>

impl<T> UnsafeUnpin for Sender<T>

impl<T> UnwindSafe for Sender<T>

impl<T, U> Into for Sender<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Sender<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Sender<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: Send> Send for Sender<T>

impl<T: Send> Sync for Sender<T>