Struct Sender
struct Sender<T> { ... }
The sending side of a channel.
Examples
use thread;
use unbounded;
let = unbounded;
let s2 = s1.clone;
spawn;
spawn;
let msg1 = r.recv.unwrap;
let msg2 = r.recv.unwrap;
assert_eq!;
Implementations
impl<T> Sender<T>
fn try_send(self: &Self, msg: T) -> Result<(), TrySendError<T>>Attempts to send a message into the channel without blocking.
This method will either send a message into the channel immediately or return an error if the channel is full or disconnected. The returned error contains the original message.
If called on a zero-capacity channel, this method will send the message only if there happens to be a receive operation on the other side of the channel at the same time.
Examples
use ; let = bounded; assert_eq!; assert_eq!; drop; assert_eq!;fn send(self: &Self, msg: T) -> Result<(), SendError<T>>Blocks the current thread until a message is sent or the channel is disconnected.
If the channel is full and not disconnected, this call will block until the send operation can proceed. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.
If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.
Examples
use thread; use Duration; use ; let = bounded; assert_eq!; spawn; assert_eq!; assert_eq!;fn send_timeout(self: &Self, msg: T, timeout: Duration) -> Result<(), SendTimeoutError<T>>Waits for a message to be sent into the channel, but only for a limited time.
If the channel is full and not disconnected, this call will block until the send operation can proceed or the operation times out. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.
If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.
Examples
use thread; use Duration; use ; let = bounded; spawn; assert_eq!; assert_eq!; assert_eq!;fn send_deadline(self: &Self, msg: T, deadline: Instant) -> Result<(), SendTimeoutError<T>>Waits for a message to be sent into the channel, but only until a given deadline.
If the channel is full and not disconnected, this call will block until the send operation can proceed or the operation times out. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.
If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.
Examples
use thread; use ; use ; let = bounded; spawn; let now = now; assert_eq!; assert_eq!; assert_eq!;fn is_empty(self: &Self) -> boolReturns
trueif the channel is empty.Note: Zero-capacity channels are always empty.
Examples
use unbounded; let = unbounded; assert!; s.send.unwrap; assert!;fn is_full(self: &Self) -> boolReturns
trueif the channel is full.Note: Zero-capacity channels are always full.
Examples
use bounded; let = bounded; assert!; s.send.unwrap; assert!;fn len(self: &Self) -> usizeReturns the number of messages in the channel.
Examples
use unbounded; let = unbounded; assert_eq!; s.send.unwrap; s.send.unwrap; assert_eq!;fn capacity(self: &Self) -> Option<usize>If the channel is bounded, returns its capacity.
Examples
use ; let = ; assert_eq!; let = ; assert_eq!; let = ; assert_eq!;fn same_channel(self: &Self, other: &Sender<T>) -> boolReturns
trueif senders belong to the same channel.Examples
use unbounded; let = ; let s2 = s.clone; assert!; let = unbounded; assert!;
impl<T> Any for Sender<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Sender<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Sender<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Clone for Sender<T>
fn clone(self: &Self) -> Self
impl<T> CloneToUninit for Sender<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Debug for Sender<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Drop for Sender<T>
fn drop(self: &mut Self)
impl<T> Freeze for Sender<T>
impl<T> From for Sender<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for Sender<T>
impl<T> SelectHandle for Sender<T>
fn try_select(self: &Self, token: &mut Token) -> boolfn deadline(self: &Self) -> Option<Instant>fn register(self: &Self, oper: Operation, cx: &Context) -> boolfn unregister(self: &Self, oper: Operation)fn accept(self: &Self, token: &mut Token, cx: &Context) -> boolfn is_ready(self: &Self) -> boolfn watch(self: &Self, oper: Operation, cx: &Context) -> boolfn unwatch(self: &Self, oper: Operation)
impl<T> ToOwned for Sender<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for Sender<T>
impl<T> UnsafeUnpin for Sender<T>
impl<T> UnwindSafe for Sender<T>
impl<T, U> Into for Sender<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Sender<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Sender<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>